==> img0ch-2.1.0.tar.bz2: img0ch/_template/type/index.cs <==
<?xml version="1.0" encoding="shift_jis"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
  "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title><?cs var:BBS_TITLE ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=shift_jis" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="generator" content="<?cs var:html_escape(VERSION ESCAPE) ?>" />
<link media="all" href="<?cs var:StaticURI ?>/tdiary/base.css?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
<link media="all" href="<?cs var:StaticURI ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:BBS_TYPE_THEME ?>/<?cs var:BBS_TYPE_THEME ?>.css<?cs else ?>default/default.css<?cs /if ?>?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
<!--meta.txto͕-->
<?cs var:META ?>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript">
//<![CDATA[
$(function () {
    $("//input[@name='FROM']").val($.cookie("NAME"));
    $("//input[@name='mail']").val($.cookie("MAIL"));
    $("form").submit(function () {
        if ( !$("textarea[@name='MESSAGE']", this).val() &&
            $("input[@type='submit']", this).val() == "" ) {
            if ( confirm("{܂Błe܂H") == false ) {
                return false;
            }
        }
        var option = { "expires": 30, "path": "<?cs var:BBS_COOKIE_PATH ?>" };
        $.cookie( "NAME", $("//input[@name='FROM']").val(), option );
        $.cookie( "MAIL", $("//input[@name='mail']").val(), option );
        $("//input[@type='submit']").attr({ "disabled": true });
        return true;
    });
});
//]]>
</script>
<style type="text/css">
/*
<![CDATA[
<!--nobanner-->
*/
a { color: <?cs var:BBS_LINK_COLOR ?>; }
a:active { color: <?cs var:BBS_ALINK_COLOR ?>; }
a:visited { color: <?cs var:BBS_VLINK_COLOR ?>; }
body { font-family: "Mona","IPA MONAPGOTHIC","MS PGothic","lr oSVbN","MS PSVbN","MS PSVbN",sans-serif; }
fieldset { border: 0px; }
img { border: 0px; }
.center { text-align:center !important;  }
.clear { clear: both !important; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; }
.nomail { color: <?cs var:BBS_NAME_COLOR ?> }
.right { text-align: right !important; }
.thread_info {}
.res_body { line-height: 100% !important; }
/* ]]> */
</style>
</head>
<body>

<div class="center" id="top">
<h1>
<?cs if:BBS_TITLE_PICTURE ?>
 <?cs if:BBS_TITLE_LINK ?>
  <a href="<?cs var:BBS_TITLE_LINK ?>">
   <img src="<?cs var:BBS_TITLE_PICTURE ?>" alt="<?cs var:BBS_TITLE ?>̊Ŕ" />
  </a>
 <?cs else ?>
  <img src="<?cs var:BBS_TITLE_PICTURE ?>" alt="<?cs var:BBS_TITLE ?>̊Ŕ" />
 <?cs /if ?>
<?cs else ?>
 <?cs var:BBS_TITLE ?>
<?cs /if ?>
</h1>
</div>

<!--[J[\-->
<div class="day" id="info">
 <h2><span class="title"><?cs var:BBS_SUBTITLE ?></span></h2>
 <div class="body">
  <div class="section">
   <?cs var:HEAD ?>
  </div>
  <!--
  <span class="center">
   <a href="../index.html" id="backTo">fꗗ</a>
  </span>
  -->
 </div>
</div>

<!--L\-->
<?cs if:Banner ?>
<hr class="sep" />
<div class="day" id="mainBanner">
 <h2><span class="title">m</span></h2>
 <div class="body">
  <div class="section">
   <?cs var:Banner ?>
  </div>
 </div>
</div>
<?cs /if ?>

<hr class="sep" />

<!--Xbhꗗ\-->
<div class="day" id="menu">
 <h2><span class="title">Xbhꗗ</span></h2>
 <div class="body">
  <div class="section" id="floated_threads">
  <?cs each:item = Threads ?>
   <a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:item.key ?>/l50"><?cs var:item.index ?>:</a>
   <a href="#f_<?cs var:item.index ?>"><?cs var:item.subject ?>(<?cs var:item.res ?>)</a><br />
  <?cs /each ?>
  </div>
  <div class="section" id="hidden_threads">
  <?cs each: item = Stored ?>
   <a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:item.key ?>/l50"><?cs var:item.index ?>:<?cs var:item.subject ?> (<?cs var:item.res ?>)</a><br />
  <?cs /each ?>
  </div>
  <div class="section" id="more_threads">
   <a href="<?cs var:BBSURI ?>/subback.html">Xbhꗗ͂</a>
  </div>
 </div>
</div>
<!--Xbhꗗ\̋؂-->

<hr class="sep" />

<!--Xbh\-->
<?cs each:t = Threads ?>
<div class="day" id="f_<?cs var:t.index ?>">
 <h2 class="thread_header">
  <span class="date">
   <span class="thread_info">y<?cs var:t.index ?>:<?cs var:t.res ?>z</span>
  </span>
  <span class="title thread_subject"><?cs var:t.subject ?></span>
 </h2>
 <div class="body thread_body" id="t_<?cs var:t.key ?>">
  <?cs each:r = t.Thread ?>
   <div class="section" id="r_<?cs var:t.key ?>_<?cs var:r.resno ?>">
    <div class="caption res_header">
     <?cs var:r.resno ?>
     OF<span class="commentator">
     <?cs if:r.mail ?>
      <a href="mailto:<?cs var:r.mail ?>" rel="nofollow"><b><?cs var:r.name ?></b></a>
     <?cs else ?>
      <span class="nomail"><b><?cs var:r.name ?></b></span>
     <?cs /if ?>
     </span>:<span class="commenttime"><?cs var:r.date ?></span>
    </div>
    <p class="res_body"><?cs var:r.text ?></p>
   </div>
  <?cs /each ?>
 </div>
 <div class="form">
  <form class="comment" method="post" action="<?cs var:CGIURI ?>/bbs.cgi" enctype="multipart/form-data">
   <div class="hidden_field">
    <input type="hidden" name="bbs" value="<?cs var:BBS ?>" />
    <input type="hidden" name="key" value="<?cs var:t.key ?>" />
    <input type="hidden" name="time" value="<?cs var:TimeStamp ?>" />
   </div>
   <div class="field name">
    OF<input type="text" name="FROM" size="19" />
   </div>
   <div class="field mail">
    [F<input type="text" name="mail" size="19" />
   </div>
   <?cs if:UploadableFromRes ?>
    <div class="textarea">摜F<input type="file" name="file" size="74" /></div>
   <?cs /if ?>
   <div class="textarea">
    RgF<textarea rows="5" cols="64" name="MESSAGE"></textarea>
   </div>
   <div class="button">
    <input type="submit" name="submit" value="" />
   </div>
  </form>
 </div>
 <div class="referer">
  <a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/">Sǂ</a>
  <a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/l50">ŐV50</a>
  <a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/1-100">1-100</a>
  <a href="#top">̃gbv</a>
  <a href="./index.html">[h</a>
  <a href="#menu"></a>
  <a href="#f_<?cs var:t.up ?>"></a>
  <a href="#f_<?cs var:t.down ?>"></a>
 </div>
</div>
<?cs /each ?>
<!--Xbh\̋؂-->

<hr class="sep" />

<!--tH[\-->
<div class="day" id="thread_builder_form">
 <h2><span class="title">XbhVK쐬</span></h2>
 <div class="form">
  <form class="comment" method="post" action="<?cs var:CGIURI ?>/bbs.cgi" enctype="multipart/form-data">
   <div class="hidden_field">
    <input type="hidden" name="bbs" value="<?cs var:BBS ?>" />
    <input type="hidden" name="time" value="<?cs var:TimeStamp ?>" />
   </div>
   <?cs if:BBS_PASSWORD_CHECK ?>
   <div class="button">
    <input type="submit" value=" VKXbh쐬ʂ " />
   </div>
   <?cs else ?>
   <div class="field">
    ^CgF<input type="text" name="subject" size="25" />
   </div>
   <div class="field name">
    OF<input type="text" name="FROM" size="19" />
   </div>
   <div class="field mail">
    E-mailF<input type="text" name="mail" size="19" />
   </div>
   <?cs if:UploadableFromRes ?>
    <div class="textarea">摜F<input type="file" name="file" size="74" /></div>
   <?cs /if ?>
   <div class="textarea">
    RgF<textarea rows="5" cols="64" name="MESSAGE"></textarea>
   </div>
   <div class="button">
    <input type="submit" name="submit" value="VKXbh쐬" />
   </div>
   <?cs /if ?>
  </form>
 </div>
</div>

<hr class="sep" />

<div class="footer">
 <?cs var:FOOT ?>
</div>

</body>
</html>

==> img0ch-2.1.4.tar.bz2: img0ch/_template/type/index.cs <==
<?xml version="1.0" encoding="shift_jis"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
  "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title><?cs var:BBS_TITLE ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=shift_jis" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="generator" content="<?cs var:html_escape(VERSION ESCAPE) ?>" />
<link media="all" href="<?cs var:StaticURI ?>/tdiary/base.css?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
<link media="all" href="<?cs var:StaticURI ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:BBS_TYPE_THEME ?>/<?cs var:BBS_TYPE_THEME ?>.css<?cs else ?>default/default.css<?cs /if ?>?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/img0ch/app.js?v=?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript">
//<![CDATA[
var app = Img0ch.App;
app.setBBSURI("<?cs var:BBSURI ?>");
app.setCGIURI("<?cs var:CGIURI ?>");
app.initForm("<?cs var:BBS_COOKIE_PATH ?>");
function redir(element) {
    app.redirectRenderer( element,
        { "theme": "<?cs var:BBS_TYPE_THEME>" } );
    return true;
}
//]]>
</script>
<style type="text/css">
/*
<![CDATA[
<!--nobanner-->
*/
a { color: <?cs var:BBS_LINK_COLOR ?>; }
a:active { color: <?cs var:BBS_ALINK_COLOR ?>; }
a:visited { color: <?cs var:BBS_VLINK_COLOR ?>; }
body { font-family: "Mona","IPA MONAPGOTHIC","MS PGothic","lr oSVbN","MS PSVbN","MS PSVbN",sans-serif; }
fieldset { border: 0px; }
img { border: 0px; }
.center { text-align:center !important;  }
.clear { clear: both !important; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; margin-right: 4px; margin-bottom: 1px; }
.nomail { color: <?cs var:BBS_NAME_COLOR ?> }
.right { text-align: right !important; }
.thread_info {}
.res_body { line-height: 110% !important; }
/* ]]> */
</style>
<!--meta.txto͕-->
<?cs var:META ?>
</head>
<body>

<div class="center" id="top">
<h1>
<?cs if:BBS_TITLE_PICTURE ?>
 <?cs if:BBS_TITLE_LINK ?>
  <a href="<?cs var:BBS_TITLE_LINK ?>">
   <img src="<?cs var:BBS_TITLE_PICTURE ?>" alt="<?cs var:BBS_TITLE ?>̊Ŕ" />
  </a>
 <?cs else ?>
  <img src="<?cs var:BBS_TITLE_PICTURE ?>" alt="<?cs var:BBS_TITLE ?>̊Ŕ" />
 <?cs /if ?>
<?cs else ?>
 <?cs var:BBS_TITLE ?>
<?cs /if ?>
</h1>
</div>

<!--[J[\-->
<div class="day" id="info">
 <h2><span class="title"><?cs var:BBS_SUBTITLE ?></span></h2>
 <div class="body">
  <div class="section">
   <?cs var:HEAD ?>
  </div>
  <!--
  <span class="center">
   <a href="../index.html" id="backTo">fꗗ</a>
  </span>
  -->
 </div>
</div>

<!--L\-->
<?cs if:Banner ?>
<hr class="sep" />
<div class="day" id="mainBanner">
 <h2><span class="title">m</span></h2>
 <div class="body">
  <div class="section">
   <?cs var:Banner ?>
  </div>
 </div>
</div>
<?cs /if ?>

<hr class="sep" />

<!--Xbhꗗ\-->
<div class="day" id="menu">
 <h2><span class="title">Xbhꗗ</span></h2>
 <div class="body">
  <div class="section" id="floated_threads">
  <?cs each:item = Threads ?>
   <a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:item.key ?>/l50" onclick="redir(this)"><?cs var:item.index ?>:</a>
   <a href="#f_<?cs var:item.index ?>"><?cs var:item.subject ?>(<?cs var:item.res ?>)</a><br />
  <?cs /each ?>
  </div>
  <div class="section" id="hidden_threads">
  <?cs each: item = Stored ?>
   <a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:item.key ?>/l50" onclick="redir(this)"><?cs var:item.index ?>:<?cs var:item.subject ?> (<?cs var:item.res ?>)</a><br />
  <?cs /each ?>
  </div>
  <div class="section" id="more_threads">
   <a href="<?cs var:BBSURI ?>/subback.html">Xbhꗗ͂</a>
  </div>
 </div>
</div>
<!--Xbhꗗ\̋؂-->

<hr class="sep" />

<!--Xbh\-->
<?cs each:t = Threads ?>
<div class="day" id="f_<?cs var:t.index ?>">
 <h2 class="thread_header">
  <span class="date">
   <span class="thread_info">y<?cs var:t.index ?>:<?cs var:t.res ?>z</span>
  </span>
  <span class="title thread_subject"><?cs var:t.subject ?></span>
 </h2>
 <div class="body thread_body" id="t_<?cs var:t.key ?>">
  <?cs each:r = t.Thread ?>
   <div class="section" id="r_<?cs var:t.key ?>_<?cs var:r.resno ?>">
    <div class="caption res_header">
     <?cs var:r.resno ?>
     OF<span class="commentator">
     <?cs if:r.mail ?>
      <a href="mailto:<?cs var:r.mail ?>" rel="nofollow"><b><?cs var:r.name ?></b></a>
     <?cs else ?>
      <span class="nomail"><b><?cs var:r.name ?></b></span>
     <?cs /if ?>
     </span>:<span class="commenttime"><?cs var:r.date ?></span>
    </div>
    <p class="res_body"><?cs var:r.text ?></p>
   </div>
  <?cs /each ?>
 </div>
 <div class="form">
  <form class="comment" method="post" action="<?cs var:CGIURI ?>/bbs.cgi" enctype="multipart/form-data">
   <div class="hidden_field">
    <input type="hidden" name="bbs" value="<?cs var:BBS ?>" />
    <input type="hidden" name="key" value="<?cs var:t.key ?>" />
    <input type="hidden" name="time" value="<?cs var:TimeStamp ?>" />
   </div>
   <div class="field name">
    OF<input type="text" name="FROM" size="19" />
   </div>
   <div class="field mail">
    [F<input type="text" name="mail" size="19" />
   </div>
   <?cs if:UploadableFromRes ?>
   <div class="field name">
    <br />摜F<input type="file" name="file" />
   </div>
   <?cs if:BBS_IMG_REQUIRE_REMOVE_KEY ?>
   <div class="field mail">
    폜pXF<input type="password" name="pass" />
   </div>
   <?cs /if ?>
   <?cs /if ?>
   <div class="textarea">
    RgF<textarea rows="5" cols="64" name="MESSAGE"></textarea>
   </div>
   <div class="button">
    <input type="submit" name="submit" value="" />
   </div>
  </form>
 </div>
 <div class="referer">
  <a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/" onclick="redir(this)">Sǂ</a>
  <a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/l50" onclick="redir(this)">ŐV50</a>
  <a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/1-100" onclick="redir(this)">1-100</a>
  <a href="#top">̃gbv</a>
  <a href="./index.html">[h</a>
  <a href="#menu"></a>
  <a href="#f_<?cs var:t.up ?>"></a>
  <a href="#f_<?cs var:t.down ?>"></a>
 </div>
</div>
<?cs /each ?>
<!--Xbh\̋؂-->

<hr class="sep" />

<!--tH[\-->
<div class="day" id="thread_builder_form">
 <h2><span class="title">XbhVK쐬</span></h2>
 <div class="form">
  <form class="comment" method="post" action="<?cs var:CGIURI ?>/bbs.cgi" enctype="multipart/form-data">
   <div class="hidden_field">
    <input type="hidden" name="bbs" value="<?cs var:BBS ?>" />
    <input type="hidden" name="time" value="<?cs var:TimeStamp ?>" />
    <input type="hidden" name="FROM" value="" />
    <input type="hidden" name="mail" value="" />
   <?cs if:BBS_PASSWORD_CHECK ?>
   </div>
   <div class="button">
    <input type="submit" value=" VKXbh쐬ʂ " />
   </div>
   <?cs else ?>
   </div>
   <div class="field">
    ^CgF<input type="text" name="subject" size="25" />
   </div>
   <div class="field name">
    OF<input type="text" name="FROM" size="19" />
   </div>
   <div class="field mail">
    E-mailF<input type="text" name="mail" size="19" />
   </div>
   <?cs if:UploadableFromRes ?>
    <div class="textarea">摜F<input type="file" name="file" size="74" /></div>
   <?cs /if ?>
   <div class="textarea">
    RgF<textarea rows="5" cols="64" name="MESSAGE"></textarea>
   </div>
   <div class="button">
    <input type="submit" name="submit" value="VKXbh쐬" />
   </div>
   <?cs /if ?>
  </form>
 </div>
</div>

<hr class="sep" />

<div class="footer">
 <?cs var:FOOT ?>
</div>

</body>
</html>
